#ifndef CONSTANTS_H
#define CONSTANTS_H

// QCoreApplication info
#define APPLICATION_NAME "simplexbmcremote"
#define ORGANIZATION_NAME "Ionutz Borcoman"

// QSettings keys
#define SETUP_XBMC_SERVER "xbmc/server"
#define SETUP_XBMC_SERVER_DEFAULT "localhost"
#define SETUP_XBMC_PORT "xbmc/evport"
#define SETUP_XBMC_PORT_DEFAULT "9777"

#define SETUP_SCREEN_DISABLE_SCREENSAVER "screen/disable_screensaver"
#define SETUP_SCREEN_DISABLE_SCREENSAVER_DEFAULT false
#define SETUP_SCREEN_DIM_TIMEOUT "screen/dim_timeout"
#define SETUP_SCREEN_DIM_TIMEOUT_DEFAULT 5
#define SETUP_SCREEN_LOCK_TIMEOUT "screen/lock_timeout"
#define SETUP_SCREEN_LOCK_TIMEOUT_DEFAULT 150
#define SETUP_SCREEN_DIM_PERCENT "screen/dim_percent"
#define SETUP_SCREEN_DIM_PERCENT_DEFAULT 20

#define SETUP_FULLSCREEN_STARTUP "screen/fullscreen_startup"
#define SETUP_FULLSCREEN_STARTUP_DEFAULT false

#define SETUP_NOTIFICATION_TIMEOUT "notification/timeout"
#define SETUP_NOTIFICATION_TIMEOUT_DEFAULT 3

#define SCREEN_DIM_TIMEOUT_MULTIPLIER 60000 // x 1 min
#define SCREEN_LOCK_TIMEOUT_MULTIPLIER 60000 // x 1 min

#define HOMEPAGE_URL "http://simple-xbmc-rem.sourceforge.net/"

#endif // CONSTANTS_H
